/*
 * fd_names.c
 *
 * This file is part of the Form Designer.
 *
 * It contains the routines that keep track of the names and
 * callback routines associated to the different objects.
 *
 * Written by Mark Overmars
 *
 * Version 2.0a
 * Date  Nov  1, 1991
 */

#include <string.h>
#include <stdio.h>
#include "fd_main.h"

/****
  THE DATA STRUCTURE
****/

typedef struct {
  FL_OBJECT *obj;       /* The object */
  char name[40];        /* Its name (if any) */
  char cbname[40];      /* Callback Routine */
  char argname[40];     /* The argument */
} OBJ;

#define MAXOBJ  2000

static OBJ objects[MAXOBJ];    /* The stored objects */
static int objnumb = 0;        /* Their number */

static int get_object_numb(FL_OBJECT *obj)
/* Returns the number of the object in the list */
{
  int i;
  for (i=0; i<objnumb; i++) if (objects[i].obj == obj) return i;
  return -1;
}

static void check_names(int on)
/* Checks whether the names are correct C-names and don't occur already. */
{
  /* Fill in argument if missing */
  if (objects[on].cbname[0] != '\0' && objects[on].argname[0] == '\0')
    strcpy(objects[on].argname,"0");
/* HAS TO BE EXTENDED */
}

/****
  ACTUAL ROUTINES
****/

void get_object_name(FL_OBJECT *obj,char *name,char *cbname,char *argname)
/* returns the names of an object */
{
  int on = get_object_numb(obj);
  name[0] = '\0'; cbname[0] = '\0'; argname[0] = '\0';
  if (on == -1) return;
  strcpy(name,objects[on].name);
  strcpy(cbname,objects[on].cbname);
  strcpy(argname,objects[on].argname);
}

void set_object_name(FL_OBJECT *obj,char *name,char *cbname,char *argname)
/* returns the names of an object */
{
  int on = get_object_numb(obj);
  if (obj == NULL) return;
  if (on == -1)
  {
    if (name[0] == '\0' && cbname[0] == '\0') return;
    if (objnumb >= MAXOBJ) return;
    objects[objnumb].obj = obj;
    on = objnumb++;
  }
  strcpy(objects[on].name,name);
  strcpy(objects[on].cbname,cbname);
  strcpy(objects[on].argname,argname);
  check_names(on);
}
